@@ -239,7 +239,7 @@ class Queue:
     @property
     def registry_cleaning_key(self):
         """Redis key used to indicate this queue has been cleaned."""
-        return 'rq:clean_registries:%s' % self.name
+        return f'rq:clean_registries:{self.name}'
 
     @property
     def scheduler_pid(self) -> Optional[int]:
@@ -480,7 +480,7 @@ class Queue:
         """Removes all "dead" jobs from the queue by cycling through it,
         while guaranteeing FIFO semantics.
         """
-        COMPACT_QUEUE = '{0}_compact:{1}'.format(self.redis_queue_namespace_prefix, uuid.uuid4())  # noqa
+        COMPACT_QUEUE = f'{self.redis_queue_namespace_prefix}_compact:{uuid.uuid4()}'  # noqa
 
         self.connection.rename(self.key, COMPACT_QUEUE)
         while True:
@@ -906,7 +906,7 @@ class Queue:
         job.ended_at = now()
         result_ttl = job.get_result_ttl(default_ttl=DEFAULT_RESULT_TTL)
         with self.connection.pipeline() as pipeline:
-            job._handle_success(result_ttl=result_ttl, pipeline=pipeline)
+            job._handle_success(result_ttl=result_ttl, pipeline=pipeline, worker_name='')
             job.cleanup(result_ttl, pipeline=pipeline)
             pipeline.execute()
         return job
@@ -1147,6 +1147,41 @@ class Queue:
 
         If Queue is instantiated with is_async=False, job is executed immediately.
 
+        Args:
+            job (Job): The job to enqueue
+            pipeline (Optional[Pipeline], optional): The Redis pipeline to use. Defaults to None.
+            at_front (bool, optional): Whether should enqueue at the front of the queue. Defaults to False.
+
+        Returns:
+            Job: The enqueued job
+        """
+        if self._is_async:
+            return self._enqueue_async_job(job, pipeline=pipeline, at_front=at_front)
+        else:
+            return self._enqueue_sync_job(job, pipeline=pipeline)
+
+    def _prepare_for_queue(self, job: 'Job', pipeline: 'Pipeline') -> None:
+        """Prepare a job for enqueueing by saving it to Redis.
+
+        This sets common job properties (status, origin, enqueued_at, timeout),
+        persists the job to Redis, and performs cleanup.
+
+        Args:
+            job (Job): The job to prepare
+            pipeline (Pipeline): The Redis pipeline to use
+        """
+        job.redis_server_version = self.get_redis_server_version()
+        job.set_status(JobStatus.QUEUED, pipeline=pipeline)
+        job.origin = self.name
+        job.enqueued_at = now()
+        if job.timeout is None:
+            job.timeout = self._default_timeout
+        job.save(pipeline=pipeline)
+        job.cleanup(ttl=job.ttl, pipeline=pipeline)
+
+    def _enqueue_async_job(self, job: 'Job', pipeline: Optional['Pipeline'] = None, at_front: bool = False) -> Job:
+        """Enqueues a job for async (delayed) execution.
+
         Args:
             job (Job): The job to enqueue
             pipeline (Optional[Pipeline], optional): The Redis pipeline to use. Defaults to None.
@@ -1159,25 +1194,34 @@ class Queue:
 
         pipe = pipeline if pipeline is not None else self.connection.pipeline()
 
-        job.redis_server_version = self.get_redis_server_version()
-        job.set_status(JobStatus.QUEUED, pipeline=pipe)
-
-        job.origin = self.name
-        job.enqueued_at = now()
-
-        if job.timeout is None:
-            job.timeout = self._default_timeout
-        job.save(pipeline=pipe)
-        job.cleanup(ttl=job.ttl, pipeline=pipe)
-
-        if self._is_async:
-            self.push_job_id(job.id, pipeline=pipe, at_front=at_front)
+        self._prepare_for_queue(job, pipe)
+        self.push_job_id(job.id, pipeline=pipe, at_front=at_front)
 
         if pipeline is None:
             pipe.execute()
 
-        if not self._is_async:
-            job = self.run_sync(job)
+        return job
+
+    def _enqueue_sync_job(self, job: 'Job', pipeline: Optional['Pipeline'] = None) -> Job:
+        """Enqueues and immediately executes a job synchronously.
+
+        Args:
+            job (Job): The job to enqueue and execute
+            pipeline (Optional[Pipeline], optional): The Redis pipeline to use. Defaults to None.
+
+        Returns:
+            Job: The executed job
+        """
+        self.log.debug('Enqueueing job %s to queue %s (sync execution)', job.id, self.name)
+
+        pipe = pipeline if pipeline is not None else self.connection.pipeline()
+
+        self._prepare_for_queue(job, pipe)
+
+        if pipeline is None:
+            pipe.execute()
+
+        job = self.run_sync(job)
 
         return job
 
@@ -1199,7 +1243,7 @@ class Queue:
             with self.connection.pipeline() as pipeline:
                 job.set_status(JobStatus.FAILED, pipeline=pipeline)
                 exc_string = ''.join(traceback.format_exception(*sys.exc_info()))
-                job._handle_failure(exc_string, pipeline)
+                job._handle_failure(exc_string, pipeline, worker_name='')
                 pipeline.execute()
 
             if job.failure_callback:
