@@ -278,6 +278,17 @@ class TestJob(RQTestCase):
         self.assertEqual(stored_job.dependency.id, parent_job.id)
         self.assertEqual(stored_job.dependency, parent_job)
 
+        # Invalid dependency types should raise ValueError
+        with self.assertRaises(ValueError):
+            Job.create(
+                func=fixtures.some_calculation,
+                depends_on=[{'id': 'not-a-job'}, parent_job.id],
+                connection=self.connection,
+            )
+
+        with self.assertRaises(ValueError):
+            Job.create(func=fixtures.some_calculation, depends_on=[parent_job, 12345], connection=self.connection)
+
     def test_persistence_of_callbacks(self):
         """Storing jobs with success and/or failure callbacks."""
         job = Job.create(
@@ -838,7 +849,7 @@ class TestJob(RQTestCase):
         job_id = 'random'
         key = Job.key_for(job_id=job_id)
 
-        assert key == (Job.redis_job_namespace_prefix + job_id).encode('utf-8')
+        assert key == Job.redis_job_namespace_prefix + job_id
 
     @min_redis_version((5, 0, 0))
     def test_blocking_result_fetch(self):
