@@ -1,4 +1,5 @@
 import json
+import multiprocessing
 import os
 import shutil
 import signal
@@ -93,9 +94,14 @@ class TestWorker(RQTestCase):
         w = Worker([fooq, barq])
         self.assertEqual(w.work(burst=True), False, 'Did not expect any work on the queue.')
 
-        fooq.enqueue(say_hello, name='Frank')
+        job = fooq.enqueue(say_hello, name='Frank')
         self.assertEqual(w.work(burst=True), True, 'Expected at least some work done.')
 
+        # Check that worker_name is stored in the result
+        result = job.latest_result()
+        self.assertIsNotNone(result)
+        self.assertEqual(result.worker_name, w.name)
+
     def test_work_and_quit_custom_serializer(self):
         """Worker processes work, then quits."""
         fooq = Queue('foo', serializer=JSONSerializer, connection=self.connection)
@@ -116,9 +122,9 @@ class TestWorker(RQTestCase):
         w2 = Worker([foo_queue], name='w2')
         w2.register_birth()
 
-        self.assertEqual(set(Worker.all(connection=foo_queue.connection)), set([w1, w2]))
-        self.assertEqual(set(Worker.all(queue=foo_queue)), set([w1, w2]))
-        self.assertEqual(set(Worker.all(queue=bar_queue)), set([w1]))
+        self.assertEqual(set(Worker.all(connection=foo_queue.connection)), {w1, w2})
+        self.assertEqual(set(Worker.all(queue=foo_queue)), {w1, w2})
+        self.assertEqual(set(Worker.all(queue=bar_queue)), {w1})
 
         w1.register_death()
         w2.register_death()
@@ -171,9 +177,7 @@ class TestWorker(RQTestCase):
         self.assertEqual(w.work(burst=True), True, 'Expected at least some work done.')
         expected_result = 'Hi there, Frank!'
         self.assertEqual(job.result, expected_result)
-        # Only run if Redis server supports streams
-        if job.supports_redis_streams:
-            self.assertEqual(Result.fetch_latest(job).return_value, expected_result)
+        self.assertEqual(job.latest_result().return_value, expected_result)
         self.assertIsNone(job.worker_name)
 
     def test_job_times(self):
@@ -192,15 +196,15 @@ class TestWorker(RQTestCase):
         job.refresh()
         self.assertTrue(
             before <= job.enqueued_at.replace(tzinfo=timezone.utc) <= after,
-            'Not %s <= %s <= %s' % (before, job.enqueued_at, after),
+            f'Not {before} <= {job.enqueued_at} <= {after}',
         )
         self.assertTrue(
             before <= job.started_at.replace(tzinfo=timezone.utc) <= after,
-            'Not %s <= %s <= %s' % (before, job.started_at, after),
+            f'Not {before} <= {job.started_at} <= {after}',
         )
         self.assertTrue(
             before <= job.ended_at.replace(tzinfo=timezone.utc) <= after,
-            'Not %s <= %s <= %s' % (before, job.ended_at, after),
+            f'Not {before} <= {job.ended_at} <= {after}',
         )
 
     def test_work_is_unreadable(self):
@@ -385,10 +389,10 @@ class TestWorker(RQTestCase):
         # Should be the original enqueued_at date, not the date of enqueueing
         # to the failed queue
         self.assertEqual(job.enqueued_at.replace(tzinfo=timezone.utc).timestamp(), enqueued_at_date.timestamp())
-        if job.supports_redis_streams:
-            result = Result.fetch_latest(job)
-            self.assertTrue(result.exc_string)
-            self.assertEqual(result.type, Result.Type.FAILED)
+        result = job.latest_result()
+        self.assertTrue(result.exc_string)
+        self.assertEqual(result.type, Result.Type.FAILED)
+        self.assertEqual(result.worker_name, w.name)
 
     def test_horse_fails(self):
         """Tests that job status is set to FAILED even if horse unexpectedly fails"""
@@ -487,6 +491,11 @@ class TestWorker(RQTestCase):
         # If a job is no longer retries, it's put in FailedJobRegistry
         self.assertIn(job, registry)
 
+        # Check that worker_name is stored in the failure result
+        result = job.latest_result()
+        self.assertIsNotNone(result)
+        self.assertEqual(result.worker_name, worker.name)
+
     def test_total_working_time(self):
         """worker.total_working_time is stored properly"""
         queue = Queue(connection=self.connection)
@@ -762,26 +771,26 @@ class TestWorker(RQTestCase):
         q = Queue(connection=self.connection)
         job = q.enqueue(say_hello, args=('Frank',), result_ttl=10)
         w = Worker([q])
-        self.assertIn(job.get_id().encode(), self.connection.lrange(q.key, 0, -1))
+        self.assertIn(job.id.encode(), self.connection.lrange(q.key, 0, -1))
         w.work(burst=True)
         self.assertNotEqual(self.connection.ttl(job.key), 0)
-        self.assertNotIn(job.get_id().encode(), self.connection.lrange(q.key, 0, -1))
+        self.assertNotIn(job.id.encode(), self.connection.lrange(q.key, 0, -1))
 
         # Job with -1 result_ttl don't expire
         job = q.enqueue(say_hello, args=('Frank',), result_ttl=-1)
         w = Worker([q])
-        self.assertIn(job.get_id().encode(), self.connection.lrange(q.key, 0, -1))
+        self.assertIn(job.id.encode(), self.connection.lrange(q.key, 0, -1))
         w.work(burst=True)
         self.assertEqual(self.connection.ttl(job.key), -1)
-        self.assertNotIn(job.get_id().encode(), self.connection.lrange(q.key, 0, -1))
+        self.assertNotIn(job.id.encode(), self.connection.lrange(q.key, 0, -1))
 
         # Job with result_ttl = 0 gets deleted immediately
         job = q.enqueue(say_hello, args=('Frank',), result_ttl=0)
         w = Worker([q])
-        self.assertIn(job.get_id().encode(), self.connection.lrange(q.key, 0, -1))
+        self.assertIn(job.id.encode(), self.connection.lrange(q.key, 0, -1))
         w.work(burst=True)
         self.assertEqual(self.connection.get(job.key), None)
-        self.assertNotIn(job.get_id().encode(), self.connection.lrange(q.key, 0, -1))
+        self.assertNotIn(job.id.encode(), self.connection.lrange(q.key, 0, -1))
 
     def test_worker_sets_job_status(self):
         """Ensure that worker correctly sets job status."""
@@ -830,6 +839,7 @@ class TestWorker(RQTestCase):
         # Test job_class as string
         worker_string = Worker([q], job_class='tests.fixtures.CustomJob')
         from tests.fixtures import CustomJob as FixturesCustomJob
+
         self.assertEqual(worker_string.job_class, FixturesCustomJob)
 
     def test_custom_queue_class(self):
@@ -866,6 +876,7 @@ class TestWorker(RQTestCase):
         # Test both job_class and queue_class as strings
         worker = Worker([q], job_class='tests.fixtures.CustomJob')
         from tests.fixtures import CustomJob as FixturesCustomJob
+
         self.assertEqual(worker.job_class, FixturesCustomJob)
 
     def test_work_via_simpleworker(self):
@@ -913,19 +924,6 @@ class TestWorker(RQTestCase):
         self.assertEqual(job._status, JobStatus.STARTED)
         self.assertEqual(job.worker_name, worker.name)
 
-    def test_cleanup_execution(self):
-        """Cleanup execution does the necessary bookkeeping."""
-        queue = Queue(connection=self.connection)
-        job = queue.enqueue(say_hello)
-        worker = Worker([queue])
-        worker.prepare_job_execution(job)
-        with self.connection.pipeline() as pipeline:
-            worker.cleanup_execution(job, pipeline=pipeline)
-            pipeline.execute()
-
-        self.assertEqual(worker.get_current_job_id(), None)
-        self.assertIsNone(worker.execution)
-
     @min_redis_version((6, 2, 0))
     def test_prepare_job_execution_removes_key_from_intermediate_queue(self):
         """Prepare job execution removes job from intermediate queue."""
@@ -1039,7 +1037,7 @@ class TestWorker(RQTestCase):
         w1 = Worker([q], name='worker1')
         w2 = Worker([q], name='worker2')
         w3 = Worker([q], name='worker1')
-        worker_set = set([w1, w2, w3])
+        worker_set = {w1, w2, w3}
         self.assertEqual(len(worker_set), 2)
 
     def test_worker_sets_birth(self):
@@ -1283,11 +1281,11 @@ class TestWorker(RQTestCase):
         self.assertEqual(worker.python_version, python_version)
 
     def test_dequeue_random_strategy(self):
-        qs = [Queue('q%d' % i, connection=self.connection) for i in range(5)]
+        qs = [Queue(f'q{i}', connection=self.connection) for i in range(5)]
 
         for i in range(5):
             for j in range(3):
-                qs[i].enqueue(say_pid, job_id='q%d_%d' % (i, j))
+                qs[i].enqueue(say_pid, job_id=f'q{i}_{j}')
 
         w = Worker(qs, connection=self.connection)
         w.work(burst=True, dequeue_strategy='random')
@@ -1295,12 +1293,12 @@ class TestWorker(RQTestCase):
         start_times = []
         for i in range(5):
             for j in range(3):
-                job = Job.fetch('q%d_%d' % (i, j), connection=self.connection)
-                start_times.append(('q%d_%d' % (i, j), job.started_at))
+                job = Job.fetch(f'q{i}_{j}', connection=self.connection)
+                start_times.append((f'q{i}_{j}', job.started_at))
         sorted_by_time = sorted(start_times, key=lambda tup: tup[1])
         sorted_ids = [tup[0] for tup in sorted_by_time]
-        expected_rr = ['q%d_%d' % (i, j) for j in range(3) for i in range(5)]
-        expected_ser = ['q%d_%d' % (i, j) for i in range(5) for j in range(3)]
+        expected_rr = [f'q{i}_{j}' for j in range(3) for i in range(5)]
+        expected_ser = [f'q{i}_{j}' for i in range(5) for j in range(3)]
 
         self.assertNotEqual(sorted_ids, expected_rr)
         self.assertNotEqual(sorted_ids, expected_ser)
@@ -1327,11 +1325,11 @@ class TestWorker(RQTestCase):
             self.assertRaises(SystemExit, worker.request_force_stop, 1, frame=None)
 
     def test_dequeue_round_robin(self):
-        qs = [Queue('q%d' % i, connection=self.connection) for i in range(5)]
+        qs = [Queue(f'q{i}', connection=self.connection) for i in range(5)]
 
         for i in range(5):
             for j in range(3):
-                qs[i].enqueue(say_pid, job_id='q%d_%d' % (i, j))
+                qs[i].enqueue(say_pid, job_id=f'q{i}_{j}')
 
         w = Worker(qs)
         w.work(burst=True, dequeue_strategy='round_robin')
@@ -1339,8 +1337,8 @@ class TestWorker(RQTestCase):
         start_times = []
         for i in range(5):
             for j in range(3):
-                job = Job.fetch('q%d_%d' % (i, j), connection=self.connection)
-                start_times.append(('q%d_%d' % (i, j), job.started_at))
+                job = Job.fetch(f'q{i}_{j}', connection=self.connection)
+                start_times.append((f'q{i}_{j}', job.started_at))
         sorted_by_time = sorted(start_times, key=lambda tup: tup[1])
         sorted_ids = [tup[0] for tup in sorted_by_time]
         expected = [
@@ -1376,6 +1374,21 @@ class TestWorker(RQTestCase):
         q.enqueue(say_hello, args=('ccc',), result_ttl=0)
         self.assertTrue(w.work(burst=True))
 
+    def test_custom_job_and_queue(self):
+        class CustomJob(Job):
+            pass
+
+        class CustomQueue(Queue):
+            pass
+
+        class CustomWorker(Worker):
+            job_class = CustomJob
+            queue_class = CustomQueue
+
+        worker = CustomWorker(CustomQueue('foo', connection=self.connection))
+        assert worker.job_class is CustomJob
+        assert worker.queue_class is CustomQueue
+
 
 def wait_and_kill_work_horse(pid, time_to_wait=0.0):
     time.sleep(time_to_wait)
@@ -1392,7 +1405,7 @@ class TimeoutTestCase:
 
     def _timeout(self, signal, frame):
         raise AssertionError(
-            "test still running after %i seconds, likely the worker wasn't shutdown correctly" % self.killtimeout
+            f"test still running after {self.killtimeout} seconds, likely the worker wasn't shutdown correctly"
         )
 
 
@@ -1532,7 +1545,7 @@ class TestWorkerSubprocess(RQTestCase):
     def setUp(self):
         super().setUp()
         db_num = self.connection.connection_pool.connection_kwargs['db']
-        self.redis_url = 'redis://127.0.0.1:6379/%d' % db_num
+        self.redis_url = f'redis://127.0.0.1:6379/{db_num}'
 
     def test_run_empty_queue(self):
         """Run the worker in its own process with an empty queue"""
@@ -1572,7 +1585,9 @@ class HerokuWorkerShutdownTestCase(TimeoutTestCase, RQTestCase):
     @slow
     def test_immediate_shutdown(self):
         """Heroku work horse shutdown with immediate (0 second) kill"""
-        p = Process(target=run_dummy_heroku_worker, args=(self.sandbox, 0, self.connection))
+        # Use 'fork' context to avoid pickling issues with Redis connections in Python 3.14+
+        ForkProcess = multiprocessing.get_context('fork').Process
+        p = ForkProcess(target=run_dummy_heroku_worker, args=(self.sandbox, 0, self.connection))
         p.start()
         time.sleep(0.5)
 
@@ -1586,7 +1601,9 @@ class HerokuWorkerShutdownTestCase(TimeoutTestCase, RQTestCase):
     @slow
     def test_1_sec_shutdown(self):
         """Heroku work horse shutdown with 1 second kill"""
-        p = Process(target=run_dummy_heroku_worker, args=(self.sandbox, 1, self.connection))
+        # Use 'fork' context to avoid pickling issues with Redis connections in Python 3.14+
+        ForkProcess = multiprocessing.get_context('fork').Process
+        p = ForkProcess(target=run_dummy_heroku_worker, args=(self.sandbox, 1, self.connection))
         p.start()
         time.sleep(0.5)
 
@@ -1602,7 +1619,9 @@ class HerokuWorkerShutdownTestCase(TimeoutTestCase, RQTestCase):
     @slow
     def test_shutdown_double_sigrtmin(self):
         """Heroku work horse shutdown with long delay but SIGRTMIN sent twice"""
-        p = Process(target=run_dummy_heroku_worker, args=(self.sandbox, 10, self.connection))
+        # Use 'fork' context to avoid pickling issues with Redis connections in Python 3.14+
+        ForkProcess = multiprocessing.get_context('fork').Process
+        p = ForkProcess(target=run_dummy_heroku_worker, args=(self.sandbox, 10, self.connection))
         p.start()
         time.sleep(0.5)
 
@@ -1623,7 +1642,9 @@ class HerokuWorkerShutdownTestCase(TimeoutTestCase, RQTestCase):
         w = HerokuWorker('foo', connection=self.connection)
 
         path = os.path.join(self.sandbox, 'shouldnt_exist')
-        p = Process(target=create_file_after_timeout_and_setpgrp, args=(path, 2))
+        # Use 'fork' context to avoid pickling issues with Redis connections in Python 3.14+
+        ForkProcess = multiprocessing.get_context('fork').Process
+        p = ForkProcess(target=create_file_after_timeout_and_setpgrp, args=(path, 2))
         p.start()
         self.assertEqual(p.exitcode, None)
         time.sleep(0.1)
@@ -1660,19 +1681,19 @@ class TestExceptionHandlerMessageEncoding(RQTestCase):
 
 class TestRoundRobinWorker(RQTestCase):
     def test_round_robin(self):
-        qs = [Queue('q%d' % i, connection=self.connection) for i in range(5)]
+        qs = [Queue(f'q{i}', connection=self.connection) for i in range(5)]
 
         for i in range(5):
             for j in range(3):
-                qs[i].enqueue(say_pid, job_id='q%d_%d' % (i, j))
+                qs[i].enqueue(say_pid, job_id=f'q{i}_{j}')
 
         w = RoundRobinWorker(qs)
         w.work(burst=True)
         start_times = []
         for i in range(5):
             for j in range(3):
-                job = Job.fetch('q%d_%d' % (i, j), connection=self.connection)
-                start_times.append(('q%d_%d' % (i, j), job.started_at))
+                job = Job.fetch(f'q{i}_{j}', connection=self.connection)
+                start_times.append((f'q{i}_{j}', job.started_at))
         sorted_by_time = sorted(start_times, key=lambda tup: tup[1])
         sorted_ids = [tup[0] for tup in sorted_by_time]
         expected = [
@@ -1697,23 +1718,23 @@ class TestRoundRobinWorker(RQTestCase):
 
 class TestRandomWorker(RQTestCase):
     def test_random_worker(self):
-        qs = [Queue('q%d' % i, connection=self.connection) for i in range(5)]
+        qs = [Queue(f'q{i}', connection=self.connection) for i in range(5)]
 
         for i in range(5):
             for j in range(3):
-                qs[i].enqueue(say_pid, job_id='q%d_%d' % (i, j))
+                qs[i].enqueue(say_pid, job_id=f'q{i}_{j}')
 
         w = RandomWorker(qs)
         w.work(burst=True)
         start_times = []
         for i in range(5):
             for j in range(3):
-                job = Job.fetch('q%d_%d' % (i, j), connection=self.connection)
-                start_times.append(('q%d_%d' % (i, j), job.started_at))
+                job = Job.fetch(f'q{i}_{j}', connection=self.connection)
+                start_times.append((f'q{i}_{j}', job.started_at))
         sorted_by_time = sorted(start_times, key=lambda tup: tup[1])
         sorted_ids = [tup[0] for tup in sorted_by_time]
-        expected_rr = ['q%d_%d' % (i, j) for j in range(3) for i in range(5)]
-        expected_ser = ['q%d_%d' % (i, j) for i in range(5) for j in range(3)]
+        expected_rr = [f'q{i}_{j}' for j in range(3) for i in range(5)]
+        expected_ser = [f'q{i}_{j}' for i in range(5) for j in range(3)]
         self.assertNotEqual(sorted_ids, expected_rr)
         self.assertNotEqual(sorted_ids, expected_ser)
         expected_rr.reverse()
